@@ -16,8 +16,9 @@
                     "readonly": "readonly"
                 }).addClass("grp-autocomplete-hidden-field");
                 // build autocomplete wrapper
-                if ($(options.content_type).val()) {
-                    $this.after(loader).after(remove_link($this.attr('id'))).after(lookup_link($this.attr("id"),$(options.content_type).val()));
+                var val = $(options.content_type).val() || $(options.content_type).find(':checked').val();
+                if (val) {
+                    $this.after(loader).after(remove_link($this.attr('id'))).after(lookup_link($this.attr("id"),val));
                 }
                 $this.parent().wrapInner("<div class='grp-autocomplete-wrapper-fk'></div>");
                 $this.parent().prepend("<input id='" + $this.attr("id") + "-autocomplete' type='text' class='vTextField' value='' />");
@@ -29,7 +30,7 @@
                     loader: $this.nextAll("div.grp-loader").hide()
                 }, $.fn.grp_autocomplete_generic.defaults, options);
                 // lookup
-                if ($(options.content_type).val()) {
+                if (val) {
                     lookup_id($this, options);  // lookup when loading page
                 }
                 lookup_autocomplete($this, options);  // autocomplete-handler
@@ -90,8 +91,9 @@
         obj.nextAll("a.related-lookup").remove();
         obj.nextAll("a.grp-related-remove").remove();
         obj.nextAll("div.grp-loader").remove();
-        if ($(elem).val()) {
-            obj.after(loader).after(remove_link(obj.attr('id'))).after(lookup_link(obj.attr('id'),$(elem).val()));
+        var val = $(elem).val() || $(elem).find(':checked').val();
+        if (val) {
+            obj.after(loader).after(remove_link(obj.attr('id'))).after(lookup_link(obj.attr('id'),val));
             options.remove_link = obj.nextAll("a.grp-related-remove").hide();
             options.loader = obj.nextAll("div.grp-loader").hide();
         }
@@ -112,9 +114,10 @@
                     $.ajax({
                         url: options.autocomplete_lookup_url,
                         dataType: 'json',
-                        data: "term=" + request.term + "&app_label=" + grappelli.get_app_label(elem) + "&model_name=" + grappelli.get_model_name(elem) + "&query_string=" + grappelli.get_query_string(elem),
+                        data: "term=" + encodeURIComponent(request.term) + "&app_label=" + grappelli.get_app_label(elem) + "&model_name=" + grappelli.get_model_name(elem) + "&query_string=" + grappelli.get_query_string(elem),
                         beforeSend: function (XMLHttpRequest) {
-                            if ($(options.content_type).val()) {
+                            var val = $(options.content_type).val() || $(options.content_type).find(':checked').val();
+                            if (val) {
                                 options.loader.show();
                             } else {
                                 return false;
@@ -175,4 +178,4 @@
         object_id: ''
     };
     
-})(grp.jQuery);
\ No newline at end of file
+})(grp.jQuery);
